@@ -12,7 +12,7 @@
 """
 
 __title__ = "wonderful_bing"
-__version__ = "0.4.3"
+__version__ = "0.5.0"
 __author__ = "lord63"
 __license__ = "MIT"
 __copyright__ = "Copyright 2014 lord63"
@@ -20,9 +20,9 @@ __copyright__ = "Copyright 2014 lord63"
 import re
 import time
 import os
+import sys
+from os import path
 import argparse
-import pynotify
-pynotify.init('Wonderful_Bing')
 
 import requests
 
@@ -35,17 +35,21 @@ class WonderfulBing(object):
         information = requests.get(self.url).json()["images"][0]
         self.copyright = information["copyright"]
         self.picture_url = information["url"]
+        if not self.picture_url.startswith('http'):
+            self.picture_url = 'http://www.bing.com' + self.picture_url
         self.directory = config['directory']
 
     def show_notify(self):
-        title = "Today's Picture Story"
-        story_content = re.match(".+(?=\()", self.copyright).group()
-        notification = pynotify.Notification(
-            title, story_content,
-            os.path.dirname(os.path.realpath(__file__)) + '/img/icon.png')
-        notification.show()
+        """show the notify to get to know the picture story"""
+        title = "Today\\'s\ Picture\ Story"
+        story_content = re.match(
+            ".+(?=\(\xa9)", self.copyright).group().encode('utf-8')
+        notify_icon = path.dirname(path.realpath(__file__)) + '/img/icon.png'
+        os.system("notify-send -a wonderful_bing -i {0} {1} '{2}'".format(
+                  notify_icon, title, story_content))
 
     def get_picture_name(self):
+        """get a nice picture name from the download url"""
         match = re.search(
             "(?<=/az/hprichbg/rb/).+?(?=_)", self.picture_url)
         picture_name = match.group() + '.jpg'
@@ -60,20 +64,20 @@ class WonderfulBing(object):
     def download_and_set(self):
         picture_name = self.get_picture_name()
         picture_path = self.directory + picture_name
-        if os.path.exists(picture_path):
+        if path.exists(picture_path):
             print "You have downloaded the picture before."
-            print "Have a look at it --> {}".format(picture_path)
-            return
+            print "Have a look at it --> {0}".format(picture_path)
+            sys.exit()
         # Sleep for two seconds, otherwise the newly setted wallpaper
         # will be setted back by the system when your system boots up
         # if you have added this script to autostart.
         time.sleep(2)
         # Set stream to true to get the raw content
-        r = requests.get(self.picture_url, stream=True)
+        request = requests.get(self.picture_url, stream=True)
         with open(picture_path, "wb") as f:
-            for chunk in r.iter_content(1024):
+            for chunk in request.iter_content(1024):
                 f.write(chunk)
-        print "Successfully download the picture to --> {}.".format(
+        print "Successfully download the picture to --> {0}.".format(
             picture_path)
         self.set_wallpaper(picture_path)
         print "Successfully set the picture as the wallpaper. :)"
@@ -85,11 +89,18 @@ def main():
         prog='wonderful_bing',
         description="Wonderful_bing's configuration")
     parser.add_argument('-V', '--version', action='version',
-                        version='%(prog)s {}'.format(__version__))
+                        version='%(prog)s {0}'.format(__version__))
     parser.add_argument(
         '-d', dest='directory',
         help="set the directory to save Bing's imgs, end with '/'")
     config = vars(parser.parse_args())
+    if not config['directory']:
+        sys.exit("Set the directory to save Bing's imgs first.\n"
+                 "For more information, use --help.")
+    if not config['directory'].endswith('/'):
+        config['directory'] = config['directory'] + '/'
+    if not path.exists(config['directory']):
+        sys.exit('No such directory :(')
 
     bing = WonderfulBing(config)
     try:
